==> nextcloud-25.0.8.tgz: nextcloud/apps/activity/l10n/mr.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "कॉपी केले!",
    "Not supported!" : "सपोर्ट करीत नाही!",
    "Press ⌘-C to copy." : "कॉपी करायला ⌘-C दाबा.",
    "Press Ctrl-C to copy." : "कॉपी करायला Ctrl-C दाबा.",
    "{name} (invisible)" : "{name} (अदृश्य)",
    "{name} (restricted)" : "{name} (प्रतिबंधित)",
    "Home" : "होम",
    "in {path}" : " {path} मध्ये",
    "Today" : "आज",
    "Yesterday" : "काल",
    "Open {filename}" : "उघडा {filename}",
    "Activity" : "क्रिया",
    "Personal activity feed for %s" : " %s करीता वैयक्तिक क्रिया फीड",
    "Your feed URL is invalid" : "तुमची फीड युआरएल अवैध आहे",
    "Your settings have been updated." : "तुमच्या सेटिंग अद्ययावत करण्यात आल्या.",
    "Settings have been updated." : "सेटिंग अद्ययावत करण्यात आल्या.",
    "Recent activity" : "अलीकडील क्रिया",
    "Daily activity summary for %s" : " %s च्या दैनंदिन क्रियांचा सारांश",
    "_and %n more _::_and %n more _" : ["आणि इतर %n","आणि इतर %n"],
    "All activities" : "सर्व क्रिया",
    "By others" : "इतरांद्वारे",
    "By you" : "तुमच्याद्वारे",
    "Hello %s" : "नमस्कार %s",
    "Hello %s," : "नमस्कार %s,",
    "There was some activity at %s" : "%s येथे काही क्रिया झाली",
    "Mail" : "मेल",
    "Push" : "पाठविलेली",
    "Notifications" : "अधिसूचना",
    "As soon as possible" : "लवकरात लवकर",
    "Hourly" : "ताशी",
    "Daily" : "दैनिक",
    "Weekly" : "साप्ताहिक",
    "No activity yet" : "अजुन कोणतीही क्रिया नाही",
    "Unable to load the activity list" : "क्रियेची यादी घेता आली नाही",
    "Enable notification emails" : "अधिसूचना ई-मेल सुरु करा",
    "Daily activity summary" : "दैनिक क्रिया सारांश",
    "No activities" : "कोणत्याही क्रिया नाहीत",
    "Default settings" : "मूळ सेटींग",
    "Activity feed" : "क्रियेची फीड"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.11.tgz: nextcloud/apps/activity/l10n/mr.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "कॉपी केले!",
    "Not supported!" : "सपोर्ट करीत नाही!",
    "Press ⌘-C to copy." : "कॉपी करायला ⌘-C दाबा.",
    "Press Ctrl-C to copy." : "कॉपी करायला Ctrl-C दाबा.",
    "{name} (invisible)" : "{name} (अदृश्य)",
    "{name} (restricted)" : "{name} (प्रतिबंधित)",
    "Home" : "होम",
    "in {path}" : " {path} मध्ये",
    "Today" : "आज",
    "Yesterday" : "काल",
    "Open {filename}" : "उघडा {filename}",
    "Activity" : "क्रिया",
    "Personal activity feed for %s" : " %s करीता वैयक्तिक क्रिया फीड",
    "Your feed URL is invalid" : "तुमची फीड युआरएल अवैध आहे",
    "Your settings have been updated." : "तुमच्या सेटिंग अद्ययावत करण्यात आल्या.",
    "Settings have been updated." : "सेटिंग अद्ययावत करण्यात आल्या.",
    "Recent activity" : "अलीकडील क्रिया",
    "No activities" : "कोणत्याही क्रिया नाहीत",
    "Daily activity summary for %s" : " %s च्या दैनंदिन क्रियांचा सारांश",
    "_and %n more _::_and %n more _" : ["आणि इतर %n","आणि इतर %n"],
    "All activities" : "सर्व क्रिया",
    "By others" : "इतरांद्वारे",
    "By you" : "तुमच्याद्वारे",
    "Hello %s" : "नमस्कार %s",
    "Hello %s," : "नमस्कार %s,",
    "There was some activity at %s" : "%s येथे काही क्रिया झाली",
    "Mail" : "मेल",
    "Push" : "पाठविलेली",
    "Notifications" : "अधिसूचना",
    "As soon as possible" : "लवकरात लवकर",
    "Hourly" : "ताशी",
    "Daily" : "दैनिक",
    "Weekly" : "साप्ताहिक",
    "No activity yet" : "अजुन कोणतीही क्रिया नाही",
    "Enable notification emails" : "अधिसूचना ई-मेल सुरु करा",
    "Daily activity summary" : "दैनिक क्रिया सारांश",
    "Default settings" : "मूळ सेटींग",
    "Activity feed" : "क्रियेची फीड",
    "Unable to load the activity list" : "क्रियेची यादी घेता आली नाही"
},
"nplurals=2; plural=(n != 1);");
